@@ -1,9 +1,10 @@
-package Alien::SDL3 0.01 {
+package Alien::SDL3 0.02 {
     use strict;
     use warnings;
     use File::ShareDir;
     use Path::Tiny;
     use Config;
+    use Alien::SDL3::ConfigData;
     #
     sub dynamic_libs {
         my $files = path( File::ShareDir::dist_dir('Alien-SDL3') )->visit(
@@ -13,18 +14,18 @@ package Alien::SDL3 0.01 {
             },
             { recurse => 1 }
         );
+        keys %$files;
     }
 
     sub features {
-        require Alien::SDL3::ConfigData;
+        my ( $self, $feature ) = @_;
+        return Alien::SDL3::ConfigData->feature($feature) if defined $feature;
         my %features = map { $_ => Alien::SDL3::ConfigData->feature($_) }
             qw[SDL3 SDL3_image SDL3_mixer SDL3_ttf];
-        return $features{ $_[1] } if defined $_[1];
         \%features;
     }
 }
 1;
-__END__
 
 =encoding utf-8
 
@@ -34,7 +35,7 @@ Alien::SDL3 - Build and install SDL3
 
 =head1 SYNOPSIS
 
-    use Alien::SDL3;
+    use Alien::SDL3; # Don't.
 
 =head1 DESCRIPTION
 
@@ -49,11 +50,11 @@ use. Just ignore it for now.
 Copyright (C) Sanko Robinson.
 
 This library is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+the terms found in the Artistic License 2. Other copyrights, terms, and
+conditions may apply to data transmitted through this module.
 
 =head1 AUTHOR
 
-
 Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 =cut
